@@ -1,6 +1,8 @@
-use graplot::Plot;
+use graplot::{Plot, x};
 
 fn main() {
+    let plot = Plot::new((|x: f64| x.sin(), x(4.)));
+    /* 
     let mut xs = [0.; 1000]; 
     
     let mut add = 0f64;
@@ -15,5 +17,7 @@ fn main() {
     }
 
     let plot = Plot::new((xs, ys));
+    */
     plot.show();
+    
 }
\ No newline at end of file
