@@ -1,6 +1,6 @@
 use graplot::Plot;
 
 fn main() {
-    let plot = Plot::new(|x: f64| x.powf(2.) - 1.);
+    let plot = Plot::new(|x: f64| x.powf(2.));
     plot.show();
 }
\ No newline at end of file
