@@ -1,16 +1,18 @@
 use macroquad::color::{Color, GREEN, RED, BLUE, YELLOW};
 
-#[derive(PartialEq)]
+#[derive(PartialEq, Clone, Copy)]
 pub enum Marker {
     Circle(f32),
     None
 }
 
+#[derive(Clone, Copy)]
 pub enum LineType {
     Solid,
     None,
 }
 
+#[derive(Clone, Copy)]
 pub struct LineDesc {
     pub color: Color,
     pub marker: Marker,
@@ -29,6 +31,8 @@ impl From<&str> for LineDesc {
         let mut line_type = LineType::None;
         let mut marker = Marker::None;
 
+        let mut radius = 5.;
+
         for char in desc.chars() {
             match char {
                 'r' => color = RED,
@@ -37,8 +41,9 @@ impl From<&str> for LineDesc {
                 'y' => color = YELLOW,
                 //cyan
                 'c' => color = Color::new(0., 1., 1., 1.), 
-                'o' => marker = Marker::Circle(5.),
+                'o' => marker = Marker::Circle(radius),
                 '-' => line_type = LineType::Solid,
+                '1' ..='9' => radius = char.to_digit(10).unwrap() as f32,
                _ => {}
             }
         }
