@@ -30,7 +30,7 @@ fn test_plot4() {
 
 #[test]
 fn test_plot5() {
-    let plot = Plot::new(([-1.6, -1.9,], "o-"));
+    let plot = Plot::new(([-1.6, -1.9,], "7o-"));
     plot.show();
 }
 
@@ -129,4 +129,10 @@ fn test_1_x() {
 
     let plot = Plot::new((xs, ys));
     plot.show();
+}
+
+#[test]
+fn test_tanh() {
+    let plot = Plot::new(|x: f64| x.tanh());
+    plot.show()
 }
\ No newline at end of file
